import React from 'react'
import { mount } from 'enzyme'
import { Provider } from 'react-redux'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import ActionCard from './ActionCard'
import { profileData } from '../../../tests/__mocks__/profile.mock'
import configureStore from 'redux-mock-store'
import { defaultEcogestureData } from '../../../tests/__mocks__/actionData.mock'
import { Button } from '@material-ui/core'
import EcogestureModal from 'components/Ecogesture/EcogestureModal'

const mockStore = configureStore([])

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockImportIconbyId = jest.fn()
jest.mock('utils/utils', () => {
  return {
    importIconbyId: jest.fn(() => {
      return mockImportIconbyId
    }),
  }
})
describe('ActionCard component', () => {
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ActionCard
          setShowList={jest.fn()}
          setSelectedAction={jest.fn()}
          action={defaultEcogestureData[1]}
        />
      </Provider>
    )
    expect(wrapper).toMatchSnapshot()
  })
  it('should open modal', () => {
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ActionCard
          setShowList={jest.fn()}
          setSelectedAction={jest.fn()}
          action={defaultEcogestureData[1]}
        />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')
    expect(wrapper.find(EcogestureModal).exists()).toBeTruthy()
  })
})
