import React, { useState, useCallback, useEffect } from 'react'
import { Ecogesture } from 'models'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { importIconbyId } from 'utils/utils'
import './actionList.scss'
import { Button } from '@material-ui/core'
import EcogestureModal from 'components/Ecogesture/EcogestureModal'
import defaultIcon from 'assets/icons/visu/ecogesture/default.svg'
import UsageEventService from 'services/usageEvent.service'
import { useClient } from 'cozy-client'
import { UsageEventType } from 'enum/usageEvent.enum'
import { useSelector } from 'react-redux'
import { AppStore } from 'store'

interface ActionCardProps {
  action: Ecogesture
  setSelectedAction: React.Dispatch<React.SetStateAction<Ecogesture | null>>
  setShowList: React.Dispatch<React.SetStateAction<boolean>>
}

const ActionCard: React.FC<ActionCardProps> = ({
  action,
  setSelectedAction,
  setShowList,
}: ActionCardProps) => {
  const [actionIcon, setActionIcon] = useState<string>('')
  const [openEcogestureModal, setOpenEcogestureModal] = useState<boolean>(false)
  const client = useClient()
  const { currentChallenge } = useSelector(
    (state: AppStore) => state.ecolyo.challenge
  )
  const toggleModal = useCallback(() => {
    setOpenEcogestureModal(prev => !prev)
  }, [])

  const selectEcogesture = useCallback(() => {
    setSelectedAction(action)
    setShowList(false)
    UsageEventService.addEvent(client, {
      type: UsageEventType.ACTION_CHANGE_EVENT,
      target: action.id,
      context: currentChallenge ? currentChallenge.id : '',
    })
    toggleModal()
  }, [
    setSelectedAction,
    setShowList,
    action,
    toggleModal,
    currentChallenge,
    client,
  ])

  useEffect(() => {
    async function handleEcogestureIcon() {
      const icon = await importIconbyId(action.id, 'ecogesture')
      if (icon) {
        setActionIcon(icon)
      } else {
        setActionIcon(defaultIcon)
      }
    }
    handleEcogestureIcon()
  }, [action])

  return (
    <>
      {action && (
        <Button key={action.id} className="action-card" onClick={toggleModal}>
          <StyledIcon className="action-icon" icon={actionIcon} size={100} />
          <div className="action-title text-18-bold">{action.shortName}</div>
        </Button>
      )}
      {action && (
        <EcogestureModal
          open={openEcogestureModal}
          ecogesture={action}
          isAction={true}
          handleCloseClick={toggleModal}
          selectEcogesture={selectEcogesture}
        />
      )}
    </>
  )
}

export default ActionCard
