import React from 'react'
import { mount } from 'enzyme'
import { Provider } from 'react-redux'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import { defaultEcogestureData } from '../../../tests/__mocks__/actionData.mock'
import { profileData } from '../../../tests/__mocks__/profile.mock'
import configureStore from 'redux-mock-store'
import { Button } from '@material-ui/core'
import ActionOnGoing from './ActionOnGoing'
import { UserActionState } from 'enum/userAction.enum'
import { DateTime } from 'luxon'
import EcogestureModal from 'components/Ecogesture/EcogestureModal'
import { UserAction } from 'models'
import { act } from 'react-dom/test-utils'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockImportIconbyId = jest.fn()
jest.mock('utils/utils', () => {
  return {
    importIconbyId: jest.fn(() => {
      return mockImportIconbyId
    }),
  }
})
const mockStore = configureStore([])

describe('ActionOnGoing component', () => {
  const userAction: UserAction = {
    ecogesture: null,
    startDate: DateTime.local().setZone('utc', {
      keepLocalTime: true,
    }),
    state: UserActionState.ONGOING,
  }
  it('should render correctly', () => {
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })

    const wrapper = mount(
      <Provider store={store}>
        <ActionOnGoing userAction={userAction} />
      </Provider>
    )

    expect(wrapper).toMatchSnapshot()
  })
  it('should click on button open ecogesture Modal', async () => {
    const userAction1: UserAction = {
      ecogesture: defaultEcogestureData[1],
      startDate: null,
      state: UserActionState.ONGOING,
    }
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ActionOnGoing userAction={userAction1} />
      </Provider>
    )
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      wrapper.update()
    })
    wrapper.find(Button).first().simulate('click')
    expect(wrapper.find(EcogestureModal).exists()).toBeTruthy()
  })
})
