import React from 'react'
import { mount } from 'enzyme'
import { Provider } from 'react-redux'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import ActionView from 'components/Action/ActionView'
import configureStore from 'redux-mock-store'
import { UserActionState } from 'enum/userAction.enum'
import ActionChoose from './ActionChoose'
import ActionOnGoing from './ActionOnGoing'
import ActionDone from './ActionDone'
import { profileData } from '../../../tests/__mocks__/profile.mock'
import { modalStateData } from '../../../tests/__mocks__/modalStateData.mock'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Content/Content', () => 'mock-content')

const mockStore = configureStore([])
describe('ActionView component', () => {
  it('should render ActionChoose component', () => {
    const userChallenge = {
      ...userChallengeData[1],
      action: {
        ...userChallengeData[1].action,
        state: UserActionState.UNSTARTED,
      },
    }
    const store = mockStore({
      ecolyo: {
        challenge: { currentChallenge: userChallenge },
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
        modal: modalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ActionView />
      </Provider>
    )
    expect(wrapper.find(ActionChoose).exists()).toBeTruthy()
    expect(wrapper).toMatchSnapshot()
  })
  it('should render ActionDone component', () => {
    const userChallenge = {
      ...userChallengeData[1],
      action: {
        ...userChallengeData[1].action,
        state: UserActionState.NOTIFICATION,
      },
    }
    const store = mockStore({
      ecolyo: {
        challenge: { currentChallenge: userChallenge },
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
        modal: modalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ActionView />
      </Provider>
    )
    expect(wrapper.find(ActionDone).exists()).toBeTruthy()
  })
  it('should render ActionOnGoing component', () => {
    const userChallenge = {
      ...userChallengeData[1],
      action: {
        ...userChallengeData[1].action,
        state: UserActionState.ONGOING,
      },
    }
    const store = mockStore({
      ecolyo: {
        challenge: { currentChallenge: userChallenge },
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        modal: modalStateData,
        profile: profileData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ActionView />
      </Provider>
    )
    expect(wrapper.find(ActionOnGoing).exists()).toBeTruthy()
  })
})
