import React, { ReactNode } from 'react'
import CardActionArea, {
  CardActionAreaProps,
} from '@material-ui/core/CardActionArea'
import CardContent from '@material-ui/core/CardContent'
import { withStyles } from '@material-ui/core/styles'

const CardBase = withStyles({
  root: {
    background: 'var(--greyLinearGradientBackground)',
    // border: '1px solid',
    boxSizing: 'border-box',
    boxShadow: '0px 4px 16px black',
    borderRadius: '4px',
    margin: '10px 0px 10px 0px',
    padding: '0.5rem 1rem',
    minHeight: '72px',
  },
})(CardActionArea)

const CardNew = withStyles({
  '@keyframes glowAnimation': {
    '0%': { boxShadow: '0px 0px 4px var(--blue)' },
    '50%': { boxShadow: '0px 0px 16px var(--blue)' },
    '100%': { boxShadow: '0px 0px 4px var(--blue)' },
  },
  root: {
    border: '1px solid var(--blue)',
    animation: '2s glowAnimation linear infinite',
    color: 'white',
    height: '100%',
    padding: 0,
  },
})(CardBase)

const CardBlueBorderContentBase = withStyles({
  root: {
    border: '1px solid var(--blue)',
    height: '100%',
    padding: 0,
  },
})(CardBase)
const CardChallengeBase = withStyles({
  root: {
    height: '100%',
    padding: 0,
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
  },
})(CardContent)

const CardContentBase = withStyles({
  root: {
    color: 'white',
    height: '100%',
    padding: 0,
  },
})(CardContent)

interface StyledEcogestureCardProps extends CardActionAreaProps {
  border?: boolean
  newEcogesture?: boolean | null
}

const GenerateContentCard = (children: ReactNode): React.ReactFragment => {
  return <CardChallengeBase>{children}</CardChallengeBase>
}

const StyledEcogestureCard: React.ComponentType<StyledEcogestureCardProps> = ({
  border,
  newEcogesture,
  ...props
}: StyledEcogestureCardProps) => {
  if (newEcogesture) {
    return <CardNew {...props}>{GenerateContentCard(props.children)}</CardNew>
  } else if (border) {
    return (
      <CardBlueBorderContentBase {...props}>
        {GenerateContentCard(props.children)}
      </CardBlueBorderContentBase>
    )
  } else {
    return (
      <CardBase {...props}>
        <CardContentBase>{props.children}</CardContentBase>
      </CardBase>
    )
  }
}

export default StyledEcogestureCard
