import React, { useCallback, useState } from 'react'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import Content from 'components/Content/Content'
import CozyBar from 'components/Header/CozyBar'
import Header from 'components/Header/Header'
import BearIcon from 'assets/icons/visu/duelResult/CHALLENGE0001-0.svg'
import { Button } from '@material-ui/core'
import { useHistory } from 'react-router-dom'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import './errorPage.scss'

interface ErrorPageProps {
  text: string
  returnPage: string
}

const ErrorPage: React.FC<ErrorPageProps> = ({
  text,
  returnPage,
}: ErrorPageProps) => {
  const history = useHistory()
  const { t } = useI18n()

  const [headerHeight, setHeaderHeight] = useState<number>(0)
  const defineHeaderHeight = (height: number) => {
    setHeaderHeight(height)
  }
  const handleClick = useCallback(() => {
    history.push(`/${returnPage}`)
  }, [history, returnPage])
  return (
    <>
      <CozyBar titleKey={'error_page.main'} />
      <Header
        setHeaderHeight={defineHeaderHeight}
        desktopTitleKey={'error_page.main'}
      ></Header>
      <Content height={headerHeight}>
        <div className="error-container">
          <StyledIcon className="profile-icon" icon={BearIcon} size={250} />

          <div className="text-18-bold head">{text}</div>
          <Button
            aria-label={t('error_page.back')}
            onClick={handleClick}
            variant={'contained'}
            classes={{
              root: 'btn-highlight',
              label: 'text-18-bold',
            }}
            type="submit"
          >
            {t('error_page.back')}
          </Button>
        </div>
      </Content>
    </>
  )
}

export default ErrorPage
