import React from 'react'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import Connection from 'components/Connection/Connection'
import { fluidStatusConnectedData } from '../../../tests/__mocks__/fluidStatusData.mock'
import * as reactRedux from 'react-redux'
import configureStore from 'redux-mock-store'
import { Provider } from 'react-redux'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'

jest.mock('components/Connection/ConnectionLogin', () => {
  return jest.fn(() => {
    return <div id="ConnectionLogin" />
  })
})

jest.mock('components/Connection/ConnectionOAuth', () => {
  return jest.fn(() => {
    return <div id="ConnectionOAuth" />
  })
})

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockStore = configureStore([])
const useDispatchSpy = jest.spyOn(reactRedux, 'useDispatch')
const useSelectorSpy = jest.spyOn(reactRedux, 'useSelector')
describe('Connection component test', () => {
  const store = mockStore({
    ecolyo: {
      global: globalStateData,
    },
  })
  it('should call ConnectionOAuth', () => {
    const wrapper = mount(
      <Provider store={store}>
        <Connection fluidStatus={fluidStatusConnectedData[2]} />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should call ConnectionLogin', () => {
    useDispatchSpy.mockReturnValue(jest.fn())
    useSelectorSpy.mockReturnValue(globalStateData)
    const wrapper = mount(
      <Provider store={store}>
        <Connection fluidStatus={fluidStatusConnectedData[0]} />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })
})
