import React, { useState, useCallback } from 'react'
import './connectionLogin.scss'

import { FluidStatus } from 'models'
import PartnerConnectionStepsModal from 'components/PartnerConnectionStepsModal/PartnerConnectionStepsModal'
import ConnectionLoginWithPartnerAccount from './ConnectionLoginWithPartnerAccount'
import ConnectionLoginNoPartnerAccount from './ConnectionLoginNoPartnerAccount'

interface ConnectionLoginProps {
  fluidStatus: FluidStatus
}

const ConnectionLogin: React.FC<ConnectionLoginProps> = ({
  fluidStatus,
}: ConnectionLoginProps) => {
  const konnectorSlug: string = fluidStatus.connection.konnectorConfig.slug
  const siteLink: string = fluidStatus.connection.konnectorConfig.siteLink

  const [openPartenerConnectionModal, setOpenPartenerConnectionModal] =
    useState<boolean>(false)
  const [hasSeenPartnerConnectionModal, setHasSeenPartnerConnectionModal] =
    useState<boolean>(false)

  const togglePartnerConnectionModal = useCallback(() => {
    setOpenPartenerConnectionModal(prev => !prev)
  }, [])

  const handleEndSteps = useCallback(() => {
    togglePartnerConnectionModal()
    window.open(siteLink, '_blank')
    setHasSeenPartnerConnectionModal(true)
  }, [siteLink, togglePartnerConnectionModal])

  return (
    <>
      {hasSeenPartnerConnectionModal ? (
        <ConnectionLoginWithPartnerAccount
          konnectorSlug={konnectorSlug}
          fluidStatus={fluidStatus}
          togglePartnerConnectionModal={togglePartnerConnectionModal}
        />
      ) : (
        <ConnectionLoginNoPartnerAccount
          konnectorSlug={konnectorSlug}
          fluidStatus={fluidStatus}
          togglePartnerConnectionModal={togglePartnerConnectionModal}
        />
      )}
      <PartnerConnectionStepsModal
        fluidType={fluidStatus.fluidType}
        open={openPartenerConnectionModal}
        handleCloseClick={togglePartnerConnectionModal}
        handleEndSteps={handleEndSteps}
      />
    </>
  )
}

export default ConnectionLogin
