import React from 'react'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import './connectionLogin.scss'
import { FluidStatus } from 'models'
import Button from '@material-ui/core/Button'
import FormLogin from 'components/Connection/FormLogin'

interface ConnectionLoginNoPartnerAccountProps {
  konnectorSlug: string
  fluidStatus: FluidStatus
  togglePartnerConnectionModal: () => void
}

const ConnectionLoginNoPartnerAccount = ({
  konnectorSlug,
  fluidStatus,
  togglePartnerConnectionModal,
}: ConnectionLoginNoPartnerAccountProps) => {
  const { t } = useI18n()

  return (
    <div className="kloginform">
      <p className={`kloginform-title ${konnectorSlug} text-20-bold`}>
        {t('auth.' + `${konnectorSlug}` + '.no_account.title')}
      </p>

      <div className="kloginform-subtitle text-18-bold">
        {t('auth.' + konnectorSlug + '.no_account.subtitle1')}
      </div>
      <div className="kloginform-button">
        <Button
          aria-label={t('auth.accessibility.button_create_account')}
          onClick={togglePartnerConnectionModal}
          classes={{
            root: 'btn-highlight',
            label: 'text-16-bold',
          }}
        >
          {t('auth.' + konnectorSlug + '.no_account.button_create_account')}
        </Button>
      </div>

      <div className="kloginform-subtitle text-18-bold">
        {t('auth.' + `${konnectorSlug}` + '.no_account.subtitle2')}
      </div>
      <div className="kloginform-infotext text-16-normal">
        {t('auth.' + `${konnectorSlug}` + '.no_account.subtitle2_info')}
      </div>
      <div className="kloginform-connect-button">
        <FormLogin fluidStatus={fluidStatus} highlightedStyle={false} />
      </div>
    </div>
  )
}

export default ConnectionLoginNoPartnerAccount
