import React, { useCallback } from 'react'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import './connectionLogin.scss'
import Button from '@material-ui/core/Button'
import { FluidStatus } from 'models'
import FormLogin from 'components/Connection/FormLogin'

interface ConnectionLoginWithPartnerAccountProps {
  konnectorSlug: string
  fluidStatus: FluidStatus
  togglePartnerConnectionModal: () => void
}

const ConnectionLoginWithPartnerAccount = ({
  konnectorSlug,
  fluidStatus,
  togglePartnerConnectionModal,
}: ConnectionLoginWithPartnerAccountProps) => {
  const { t } = useI18n()

  const goToGuide = useCallback(() => {
    window.open(
      'https://www.notion.so/Besoin-d-aide-d3afe29ba5aa42bb9d49eecfcb506c72',
      '_blank'
    )
  }, [])

  return (
    <div className="kloginform">
      <p className={`kloginform-title ${konnectorSlug} text-20-bold`}>
        {t('auth.' + `${konnectorSlug}` + '.with_account.title')}
      </p>

      <div className="kloginform-subtitle text-18-bold">
        {t('auth.' + konnectorSlug + '.with_account.subtitle1')}
      </div>
      <div className="kloginform-connect-button">
        <FormLogin fluidStatus={fluidStatus} highlightedStyle={true} />
      </div>
      {konnectorSlug === 'grdfgrandlyon' && (
        <div className="kloginform-infotext text-16-normal">
          {t('auth.' + konnectorSlug + '.with_account.subtitle1_info')}
        </div>
      )}

      <div className="kloginform-subtitle text-18-bold">
        {t('auth.' + konnectorSlug + '.with_account.subtitle2')}
      </div>
      <div className="kloginform-button">
        <Button
          aria-label={t('auth.accessibility.button_create_account')}
          onClick={togglePartnerConnectionModal}
          classes={{
            root: 'btn-secondary-negative',
            label: 'text-16-bold',
          }}
        >
          {t('auth.' + konnectorSlug + '.with_account.button_create_account')}
        </Button>
      </div>

      <div className="kloginform-infotext text-16-normal">
        {t('auth.' + `${konnectorSlug}` + '.with_account.subtitle2_info')}
      </div>
      <div className="kloginform-button">
        <Button
          aria-label={t('auth.accessibility.button_goto_guide')}
          onClick={goToGuide}
          classes={{
            root: 'btn-secondary-negative',
            label: 'text-16-bold',
          }}
        >
          {t('auth.' + konnectorSlug + '.with_account.button_goto_guide')}
        </Button>
      </div>
    </div>
  )
}

export default ConnectionLoginWithPartnerAccount
