import React, { useCallback } from 'react'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Dialog from '@material-ui/core/Dialog'
import CloseIcon from 'assets/icons/ico/close.svg'
import GrdfIcon from 'assets/icons/ico/consent-outdated-grdf.svg'
import Icon from 'cozy-ui/transpiled/react/Icon'
import { Button, IconButton } from '@material-ui/core'
import './deleteGRDFAccountModal.scss'

interface DeleteGRDFAccountModalProps {
  open: boolean
  handleCloseClick: () => void
  deleteAccount: () => void
}

const DeleteGRDFAccountModal: React.FC<DeleteGRDFAccountModalProps> = ({
  open,
  handleCloseClick,
  deleteAccount,
}: DeleteGRDFAccountModalProps) => {
  const { t } = useI18n()

  const handleDelete = useCallback(() => {
    deleteAccount()
    handleCloseClick()
  }, [deleteAccount, handleCloseClick])

  return (
    <Dialog
      open={open}
      onClose={handleCloseClick}
      aria-labelledby={'accessibility-title'}
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id={'accessibility-title'}>
        {t('consumption_visualizer.modal.window_title')}
      </div>
      <IconButton
        aria-label={t('consumption_visualizer.modal.close')}
        className="modal-paper-close-button"
        onClick={handleCloseClick}
      >
        <Icon icon={CloseIcon} size={16} />
      </IconButton>
      <div className="delete-grdf-modal">
        <div className="icon-main">
          <Icon icon={GrdfIcon} size={135} />
        </div>

        <div className={`text-15-normal text1`}>
          {t(`delete_grdf_modal.text1`)}
        </div>
        <div className="text-16-normal text2">
          {t(`delete_grdf_modal.text2`)}
        </div>
        <div className="text-15-normal text3">
          {t(`delete_grdf_modal.text3`)}
        </div>
        <div className="buttons">
          <Button
            aria-label={t(`delete_grdf_modal.cancel`)}
            onClick={handleCloseClick}
            classes={{
              root: 'btn-secondary-positive',
              label: 'text-16-normal',
            }}
          >
            {t(`delete_grdf_modal.cancel`)}
          </Button>
          <Button
            aria-label={t(`delete_grdf_modal.go`)}
            onClick={handleDelete}
            classes={{
              root: 'btn-highlight',
              label: 'text-16-bold',
            }}
          >
            {t(`delete_grdf_modal.go`)}
          </Button>
        </div>
      </div>
    </Dialog>
  )
}

export default DeleteGRDFAccountModal
