import React from 'react'
import { mount } from 'enzyme'
import configureStore from 'redux-mock-store'
import { Provider } from 'react-redux'
import { globalStateData } from '../../../../tests/__mocks__/globalStateData.mock'
import toJson from 'enzyme-to-json'
import SgeConnectView from './SgeConnectView'
import * as reactRedux from 'react-redux'
import { SgeStep } from 'enum/sgeStep.enum'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
jest.mock('components/Content/Content', () => 'mock-content')
jest.mock('components/FormGlobal/FormProgress', () => 'mock-formprogress')

const mockStore = configureStore([])
const useDispatchSpy = jest.spyOn(reactRedux, 'useDispatch')

describe('SgeConnectView component', () => {
  beforeEach(() => {
    useDispatchSpy.mockReset()
  })
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <SgeConnectView />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should render address Step', () => {
    const store = mockStore({
      ecolyo: {
        global: {
          ...globalStateData,
          sgeConnect: {
            ...globalStateData.sgeConnect,
            currentStep: SgeStep.Address,
          },
        },
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <SgeConnectView />
      </Provider>
    )
    expect(wrapper.find('.stepAddress')).toBeTruthy()
  })
  it('should render identity Step', () => {
    const store = mockStore({
      ecolyo: {
        global: {
          ...globalStateData,
          sgeConnect: {
            ...globalStateData.sgeConnect,
            currentStep: SgeStep.IdentityAndPDL,
          },
        },
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <SgeConnectView />
      </Provider>
    )
    expect(wrapper.find('.stepIdentity')).toBeTruthy()
  })
  it('should render consent Step', () => {
    const store = mockStore({
      ecolyo: {
        global: {
          ...globalStateData,
          sgeConnect: {
            ...globalStateData.sgeConnect,
            currentStep: SgeStep.Consent,
          },
        },
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <SgeConnectView />
      </Provider>
    )
    expect(wrapper.find('.stepConsent')).toBeTruthy()
  })
  it('should render default Step', () => {
    const store = mockStore({
      ecolyo: {
        global: {
          ...globalStateData,
          sgeConnect: {
            ...globalStateData.sgeConnect,
            currentStep: 99,
          },
        },
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <SgeConnectView />
      </Provider>
    )
    expect(wrapper.find('.stepIdentity')).toBeTruthy()
  })
  describe('SgeConnectView Navigation methods', () => {
    beforeEach(() => {
      useDispatchSpy.mockReset()
    })
    it('should call nextStep method', () => {
      const store = mockStore({
        ecolyo: {
          global: globalStateData,
        },
      })
      const wrapper = mount(
        <Provider store={store}>
          <SgeConnectView />
        </Provider>
      )
      wrapper.find('.profile-navigation-button').last().simulate('click')
      expect(useDispatchSpy).toHaveBeenCalled()
    })
    it('shouldnt call disabled nextStep method', () => {
      const store = mockStore({
        ecolyo: {
          global: globalStateData,
        },
      })
      const wrapper = mount(
        <Provider store={store}>
          <SgeConnectView />
        </Provider>
      )
      wrapper.find('.profile-navigation-button').last().simulate('click')
      expect(useDispatchSpy).toHaveBeenCalled()
    })
  })
})
