import React from 'react'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import { FluidType } from 'enum/fluid.enum'
import { baseDataLoad } from '../../../tests/__mocks__/datachartData.mock'
import { DataloadSectionType, DataloadState } from 'enum/dataload.enum'
import { Dataload } from 'models'
import DataloadSectionDetail from './DataloadSectionDetail'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

describe('DataloadSectionDetail component', () => {
  const mockDataload: Dataload = baseDataLoad

  it('should render correctly', () => {
    const wrapper = mount(
      <DataloadSectionDetail
        dataload={mockDataload}
        fluidType={FluidType.ELECTRICITY}
        dataloadSectionType={DataloadSectionType.NO_COMPARE}
      />
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should not display if multifluid and comparison', () => {
    const wrapper = mount(
      <DataloadSectionDetail
        dataload={mockDataload}
        fluidType={FluidType.MULTIFLUID}
        dataloadSectionType={DataloadSectionType.RIGHT}
      />
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should not display value details if multifluid, no valueDetail and comparison', () => {
    const mockMultiDataload: Dataload = {
      ...mockDataload,
      state: DataloadState.AGGREGATED_EMPTY,
      valueDetail: null,
    }
    const wrapper = mount(
      <DataloadSectionDetail
        dataload={mockMultiDataload}
        fluidType={FluidType.MULTIFLUID}
        dataloadSectionType={DataloadSectionType.RIGHT}
      />
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  describe('should display value details if multifluid and no comparison', () => {
    it('case all valid data', () => {
      const mockMultiDataload: Dataload = {
        ...mockDataload,
        state: DataloadState.AGGREGATED_VALID,
        valueDetail: [
          { value: 1, state: DataloadState.VALID },
          { value: 2, state: DataloadState.VALID },
          { value: 3, state: DataloadState.VALID },
        ],
      }
      const wrapper = mount(
        <DataloadSectionDetail
          dataload={mockMultiDataload}
          fluidType={FluidType.MULTIFLUID}
          dataloadSectionType={DataloadSectionType.RIGHT}
        />
      )
      expect(toJson(wrapper)).toMatchSnapshot()
    })
    it('case valid and coming data', () => {
      const mockMultiDataload: Dataload = {
        ...mockDataload,
        state: DataloadState.AGGREGATED_WITH_COMING,
        valueDetail: [
          { value: 1, state: DataloadState.VALID },
          { value: -1, state: DataloadState.COMING },
          { value: 3, state: DataloadState.VALID },
        ],
      }
      const wrapper = mount(
        <DataloadSectionDetail
          dataload={mockMultiDataload}
          fluidType={FluidType.MULTIFLUID}
          dataloadSectionType={DataloadSectionType.RIGHT}
        />
      )
      expect(toJson(wrapper)).toMatchSnapshot()
    })
    it('case valid and missing data', () => {
      const mockMultiDataload: Dataload = {
        ...mockDataload,
        state: DataloadState.AGGREGATED_WITH_HOLE_OR_MISSING,
        valueDetail: [
          { value: 1, state: DataloadState.VALID },
          { value: -1, state: DataloadState.MISSING },
          { value: 3, state: DataloadState.VALID },
        ],
      }
      const wrapper = mount(
        <DataloadSectionDetail
          dataload={mockMultiDataload}
          fluidType={FluidType.MULTIFLUID}
          dataloadSectionType={DataloadSectionType.RIGHT}
        />
      )
      expect(toJson(wrapper)).toMatchSnapshot()
    })
    it('case valid and hole data', () => {
      const mockMultiDataload: Dataload = {
        ...mockDataload,
        state: DataloadState.AGGREGATED_WITH_HOLE_OR_MISSING,
        valueDetail: [
          { value: 1, state: DataloadState.VALID },
          { value: -1, state: DataloadState.HOLE },
          { value: 3, state: DataloadState.VALID },
        ],
      }
      const wrapper = mount(
        <DataloadSectionDetail
          dataload={mockMultiDataload}
          fluidType={FluidType.MULTIFLUID}
          dataloadSectionType={DataloadSectionType.RIGHT}
        />
      )
      expect(toJson(wrapper)).toMatchSnapshot()
    })
  })
})
