import React, { useCallback, useEffect } from 'react'
import './content.scss'
import { useSelector, useDispatch } from 'react-redux'
import { AppStore } from 'store'
import { changeScreenType } from 'store/global/global.actions'
import { updateModalIsFeedbacksOpen } from 'store/modal/modal.actions'
import { ScreenType } from 'enum/screen.enum'
import FeedbackModal from 'components/Feedback/FeedbackModal'
import { useHistory } from 'react-router-dom'
interface ContentProps {
  children?: React.ReactNode
  height?: number
  background?: string
}

const Content: React.FC<ContentProps> = ({
  children,
  height = 0,
  background = 'inherit',
}: ContentProps) => {
  const dispatch = useDispatch()
  const history = useHistory()
  const { screenType } = useSelector((state: AppStore) => state.ecolyo.global)
  const { isFeedbacksOpen } = useSelector(
    (state: AppStore) => state.ecolyo.modal
  )

  const cozyBarHeight = 48
  const cozyNavHeight = 56

  const handleFeedbackModalClose = useCallback(() => {
    dispatch(updateModalIsFeedbacksOpen(false))
  }, [dispatch])

  // Scroll handling
  const app = document.querySelector('.app-content')

  /**
   * Handle Desktop scroll
   */
  const handleWindowScroll = useCallback(() => {
    app?.scrollTo(0, 0)
    window.scrollTo(0, 0)
  }, [app])

  // Set listners for scroll
  useEffect(() => {
    const listner = history.listen(handleWindowScroll)
    return () => {
      // remove listner subscription
      listner()
    }
  }, [handleWindowScroll, history])

  useEffect(() => {
    function handleResize() {
      if (innerWidth <= 768) {
        dispatch(changeScreenType(ScreenType.MOBILE))
      } else if (innerWidth <= 1024) {
        dispatch(changeScreenType(ScreenType.TABLET))
      } else {
        dispatch(changeScreenType(ScreenType.DESKTOP))
      }
    }
    handleResize()
    window.addEventListener('resize', handleResize)
    return () => {
      window.removeEventListener('resize', handleResize)
    }
  }, [dispatch])

  return (
    <>
      <FeedbackModal
        open={isFeedbacksOpen}
        handleCloseClick={handleFeedbackModalClose}
      />
      <div
        className={'content-view'}
        style={{
          marginTop: height,
          paddingBottom: 0,
          minHeight:
            screenType !== ScreenType.DESKTOP
              ? `calc(100vh - ${height}px - ${cozyBarHeight}px - ${cozyNavHeight}px - env(safe-area-inset-top) - env(safe-area-inset-bottom) - env(safe-area-inset-bottom))`
              : `unset`,
          background: background,
        }}
      >
        {children}
      </div>
    </>
  )
}

export default Content
