import { TimeStep } from 'enum/timeStep.enum'
import { DateTime } from 'luxon'
import React from 'react'
import './datenavigatorformat.scss'

interface DateNavigatorFormatProps {
  timeStep: TimeStep
  date: DateTime
  inline: boolean
}

const DateNavigatorFormat: React.FC<DateNavigatorFormatProps> = ({
  timeStep,
  date,
  inline,
}: DateNavigatorFormatProps) => {
  const formatDate = (_timeStep: TimeStep) => {
    switch (_timeStep) {
      case TimeStep.YEAR:
        return [
          date.toLocaleString({
            year: 'numeric',
          }),
          '',
        ]
      case TimeStep.MONTH:
        return [
          date.toLocaleString({
            month: 'long',
          }),
          date.toLocaleString({
            year: 'numeric',
          }),
        ]
      case TimeStep.DAY:
      case TimeStep.WEEK:
        return [
          date.toLocaleString({
            weekday: 'long',
            day: '2-digit',
          }),
          date.toLocaleString({
            month: 'long',
          }),
        ]
      case TimeStep.HALF_AN_HOUR:
        /**
         * Format date to range:
         * 9:00 - 9:30
         * Day 0X Month
         */
        return [
          `${date.toLocaleString({
            hour: 'numeric',
            minute: 'numeric',
          })} -
         ${date.plus({ minutes: 30 }).toLocaleString({
           hour: 'numeric',
           minute: 'numeric',
         })}`,
          date.toLocaleString({
            weekday: 'long',
            day: '2-digit',
            month: 'long',
          }),
        ]
      default:
        return [date.toLocaleString(DateTime.DATETIME_SHORT), '']
    }
  }
  const formatedDate = formatDate(timeStep)

  return (
    <div className="date-navigator-format">
      {inline ? (
        <>
          {formatedDate[0] && formatedDate[1] && (
            <div className="date-navigator-format-date text-16-bold">
              {formatedDate[0]} {formatedDate[1]}
            </div>
          )}
        </>
      ) : (
        <>
          {formatedDate[0] && (
            <div className="date-navigator-format-date text-16-bold timeRange">
              {formatedDate[0]}
            </div>
          )}
          {formatedDate[1] && (
            <div className="date-navigator-format-date text-15-normal">
              {formatedDate[1]}
            </div>
          )}
        </>
      )}
    </div>
  )
}

export default DateNavigatorFormat
