import React from 'react'
import { mount } from 'enzyme'
import { Provider } from 'react-redux'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import { profileData } from '../../../tests/__mocks__/profile.mock'
import configureStore from 'redux-mock-store'

import { act } from 'react-dom/test-utils'
import DuelResultModal from './DuelResultModal'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockImportIconbyId = jest.fn()
const mockFormatNumberValues = jest.fn()
jest.mock('utils/utils', () => {
  return {
    importIconbyId: jest.fn(() => {
      return mockImportIconbyId
    }),
    formatNumberValues: jest.fn(() => {
      return mockFormatNumberValues
    }),
  }
})
const mockStore = configureStore([])

describe('DuelResultModal component', () => {
  it('should render correctly', async () => {
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    mockImportIconbyId.mockReturnValue('')
    const wrapper = mount(
      <Provider store={store}>
        <DuelResultModal
          open={true}
          handleCloseClick={jest.fn()}
          userChallenge={userChallengeData[1]}
          win={true}
        />
      </Provider>
    )
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      wrapper.update()
    })
    expect(wrapper).toMatchSnapshot()
  })
  it('should render a loss modal', async () => {
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    mockImportIconbyId.mockReturnValue('')

    const wrapper = mount(
      <Provider store={store}>
        <DuelResultModal
          open={true}
          handleCloseClick={jest.fn()}
          userChallenge={userChallengeData[1]}
          win={false}
        />
      </Provider>
    )
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      wrapper.update()
    })
    expect(wrapper.find('.title').text()).toBe('duel_result_modal.lost.title')
  })
})
