import React from 'react'
import { mount } from 'enzyme'
import EcogestureModal from 'components/Ecogesture/EcogestureModal'
import { ecogesturesData } from '../../../tests/__mocks__/ecogesturesData.mock'
import configureStore from 'redux-mock-store'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { challengeStateData } from '../../../tests/__mocks__/challengeStateData.mock'
import { Provider } from 'react-redux'
import { act } from 'react-dom/test-utils'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockImportIconbyId = jest.fn()
jest.mock('utils/utils', () => {
  return {
    importIconbyId: jest.fn(() => {
      return mockImportIconbyId
    }),
  }
})

const mockStore = configureStore([])

describe('EcogestureModal component', () => {
  it('should be rendered correctly', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })

    const wrapper = mount(
      <Provider store={store}>
        <EcogestureModal
          open={true}
          ecogesture={ecogesturesData[0]}
          isAction={false}
          handleCloseClick={jest.fn()}
        />
      </Provider>
    )
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      wrapper.update()
    })
    expect(wrapper.find('.em-title').text()).toEqual(
      ecogesturesData[0].shortName
    )
  })
})
