/* eslint-disable react/display-name */
import React from 'react'
import { mount } from 'enzyme'
import { Provider } from 'react-redux'
import SingleEcogesture from 'components/Ecogesture/SingleEcogesture'
import toJson from 'enzyme-to-json'
import { challengeStateData } from '../../../tests/__mocks__/challengeStateData.mock'
import { ecogesturesData } from '../../../tests/__mocks__/ecogesturesData.mock'
import configureStore from 'redux-mock-store'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockImportIconbyId = jest.fn()
jest.mock('utils/utils', () => {
  return {
    importIconbyId: () => mockImportIconbyId,
  }
})

jest.mock('components/Ecogesture/EfficientyRating', () => () => (
  <div id="EfficientyRating"></div>
))
jest.mock('components/Header/Header', () => () => <div id="Header"></div>)
jest.mock('components/Header/CozyBar', () => () => <div id="CozyBar"></div>)
jest.mock('components/Loader/Loader', () => () => <div id="spinner"></div>)
// eslint-disable-next-line @typescript-eslint/no-explicit-any
jest.mock('components/Content/Content', () => (props: any) => (
  <div id="content">{props.children}</div>
))

const mockgetEcogesturesByIds = jest.fn()
const mockupdateEcogesture = jest.fn()
jest.mock('services/ecogesture.service', () => {
  return jest.fn(() => {
    return {
      getEcogesturesByIds: mockgetEcogesturesByIds,
      updateEcogesture: mockupdateEcogesture,
    }
  })
})

const mockStore = configureStore([])

jest.mock('react-router-dom', () => ({
  useLocation: jest.fn().mockReturnValue({
    state: { selectionCompleted: true },
  }),
  useHistory: () => jest.fn(),
}))

describe('SingleEcogesture component', () => {
  it('should be rendered correctly', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })

    mockgetEcogesturesByIds.mockResolvedValue([ecogesturesData[0]])
    const wrapper = mount(
      <Provider store={store}>
        <SingleEcogesture
          match={{
            params: { id: 'ECOGESTURE0001' },
          }}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should change doing status', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })

    mockgetEcogesturesByIds.mockResolvedValue([ecogesturesData[0]])
    mockImportIconbyId.mockReturnValue('')
    const updatedEcogesture = { ...ecogesturesData[0], doing: true }
    mockupdateEcogesture.mockResolvedValueOnce(updatedEcogesture)
    const wrapper = mount(
      <Provider store={store}>
        <SingleEcogesture
          match={{
            params: { id: 'ECOGESTURE0001' },
          }}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find('.doing-btn').first().simulate('click')
    await waitForComponentToPaint(wrapper)

    expect(mockupdateEcogesture).toHaveBeenCalledWith(updatedEcogesture)
  })
  it('should change objective status', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })

    mockgetEcogesturesByIds.mockResolvedValue([ecogesturesData[0]])
    mockImportIconbyId.mockReturnValue('icontest')
    const updatedEcogesture = { ...ecogesturesData[0], objective: true }
    mockupdateEcogesture.mockResolvedValueOnce(updatedEcogesture)

    const wrapper = mount(
      <Provider store={store}>
        <SingleEcogesture
          match={{
            params: { id: 'ECOGESTURE0001' },
          }}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find('.objective-btn').first().simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(mockupdateEcogesture).toHaveBeenCalledWith(updatedEcogesture)
  })
  it('should toggle more details', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })

    mockgetEcogesturesByIds.mockResolvedValue([ecogesturesData[0]])
    mockImportIconbyId.mockReturnValue(undefined)

    const wrapper = mount(
      <Provider store={store}>
        <SingleEcogesture
          match={{
            params: { id: 'ECOGESTURE0001' },
          }}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)

    wrapper.find('.toggle-text').first().simulate('click')
    await waitForComponentToPaint(wrapper)

    expect(wrapper.find('.toggle-text').text()).toBe(
      'ecogesture_modal.show_less'
    )
  })
})
