import React, { useEffect, useState } from 'react'
import 'components/ProfileType/profileTypeForm.scss'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { importIconbyId } from 'utils/utils'
import Icon from 'cozy-ui/transpiled/react/Icon'

interface EquipmentIconProps {
  equipment: string
  isChecked: boolean
}

const EquipmentIcon: React.FC<EquipmentIconProps> = ({
  equipment,
  isChecked,
}: EquipmentIconProps) => {
  const { t } = useI18n()
  const [icon, setIcon] = useState<string>('')
  useEffect(() => {
    let subscribed = true
    async function getIcon() {
      const svg = await importIconbyId(equipment, 'equipments')
      if (subscribed && svg) {
        setIcon(svg)
      }
    }
    getIcon()
    return () => {
      subscribed = false
    }
  }, [equipment])
  return (
    <>
      <div
        className={
          isChecked
            ? 'equipment-icon-container checked'
            : ' equipment-icon-container'
        }
      >
        <Icon icon={icon} size={40} className={'equipmentIcon '} />
      </div>
      <div className="text text-14-normal">
        {t(`ecogesture_profile.equipments.${equipment.toLocaleLowerCase()}`)}
      </div>
    </>
  )
}

export default EquipmentIcon
