import React, { useCallback } from 'react'
import './ecogestureSelectionRestart.scss'
import { useHistory } from 'react-router-dom'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import icon from 'assets/icons/visu/ecogesture/ECOGESTURE0001.svg'
import { Button } from '@material-ui/core'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'

interface EcogestureSelectionRestartProps {
  listLength: number
  restart: () => void
}

const EcogestureSelectionRestart: React.FC<EcogestureSelectionRestartProps> = ({
  listLength,
  restart,
}: EcogestureSelectionRestartProps) => {
  const { t } = useI18n()
  const history = useHistory()

  const goToObjectives = useCallback(() => {
    history.push('/ecogestures?tab=0')
  }, [history])

  return (
    <div className="eg-selection-restart-container">
      <div className="content">
        <div className="title text-21-bold">
          {t('ecogesture_selection.title', {
            // eslint-disable-next-line camelcase
            smart_count: listLength,
          })}
        </div>
        <StyledIcon icon={icon} size={120} />
        <div className="text text-16-normal">
          {t('ecogesture_selection.text')}
        </div>
      </div>
      <div className="buttons">
        <Button
          aria-label={t(
            'ecogesture_selection.accessibility.button_go_to_ecogesture'
          )}
          classes={{
            root: 'btn-secondary-negative',
            label: 'text-16-normal',
          }}
          onClick={goToObjectives}
        >
          {t('ecogesture_selection.button_go_to_ecogesture')}
        </Button>
        <Button
          aria-label={t('ecogesture_selection.accessibility.button_continue')}
          classes={{
            root: 'btn-highlight',
            label: 'text-16-bold',
          }}
          onClick={restart}
        >
          {t('ecogesture_selection.button_continue')}
        </Button>
      </div>
    </div>
  )
}

export default EcogestureSelectionRestart
