import React, { useCallback } from 'react'
import './explorationFinished.scss'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import starResult from 'assets/icons/visu/quiz/starResult.svg'
import Button from '@material-ui/core/Button'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { UserChallenge } from 'models'
import { useHistory } from 'react-router-dom'
import { UserExplorationState } from 'enum/userExploration.enum'
import { UserChallengeUpdateFlag } from 'enum/userChallenge.enum'
import { updateUserChallengeList } from 'store/challenge/challenge.actions'
import ChallengeService from 'services/challenge.service'
import { Client, useClient } from 'cozy-client'
import { useDispatch } from 'react-redux'
import { toggleChallengeExplorationNotification } from 'store/global/global.actions'
import { UsageEventType } from 'enum/usageEvent.enum'
import UsageEventService from 'services/usageEvent.service'

interface ExplorationFinishedProps {
  userChallenge: UserChallenge
}

const ExplorationFinished: React.FC<ExplorationFinishedProps> = ({
  userChallenge,
}: ExplorationFinishedProps) => {
  const client: Client = useClient()
  const { t } = useI18n()
  const dispatch = useDispatch()
  const history = useHistory()

  const checkNotificationToEnd = useCallback(async () => {
    const challengeService = new ChallengeService(client)
    if (userChallenge.exploration.state === UserExplorationState.NOTIFICATION) {
      const updatedChallenge = await challengeService.updateUserChallenge(
        userChallenge,
        UserChallengeUpdateFlag.EXPLORATION_DONE
      )
      await UsageEventService.addEvent(client, {
        type: UsageEventType.EXPLORATION_END_EVENT,
        target: userChallenge.exploration.id,
        context: userChallenge.id,
        startDate: userChallenge.exploration.date,
      })
      dispatch(toggleChallengeExplorationNotification(false))
      dispatch(updateUserChallengeList(updatedChallenge))
    }
  }, [client, dispatch, userChallenge])

  const goBack = useCallback(async () => {
    await checkNotificationToEnd()
    history.goBack()
  }, [history, checkNotificationToEnd])

  return (
    <div className="exploration-card">
      <div className="exploration-finish">
        <div className="congratulation">{t('exploration.congratulation')}</div>
        <div className="msg-sucess">
          {userChallenge.exploration.message_success}
        </div>
        <div className="exploration-earn">{t('exploration.earn')}</div>
        <div className="score-stars">
          5
          <StyledIcon
            className="exploration-icon"
            icon={starResult}
            size={30}
            role="img"
            title="Etoiles"
            ariaHidden={false}
          />
        </div>
        <Button
          aria-label={t('exploration.accessibility.button_confirm')}
          onClick={goBack}
          classes={{
            root: 'btn-secondary-negative',
            label: 'text-16-normal',
          }}
        >
          {t('exploration.button_confirm')}
        </Button>
      </div>
    </div>
  )
}

export default ExplorationFinished
