import React, { useCallback, useState } from 'react'
import { useSelector } from 'react-redux'
import { AppStore } from 'store'
import CozyBar from 'components/Header/CozyBar'
import Content from 'components/Content/Content'
import Header from 'components/Header/Header'
import { UserExplorationState } from 'enum/userExploration.enum'
import { UserChallenge } from 'models'
import ExplorationOngoing from './ExplorationOngoing'
import ExplorationError from './ExplorationError'
import ExplorationFinished from './ExplorationFinished'

const ExplorationView: React.FC = () => {
  const [headerHeight, setHeaderHeight] = useState<number>(0)
  const { currentChallenge } = useSelector(
    (state: AppStore) => state.ecolyo.challenge
  )

  const defineHeaderHeight = useCallback((height: number) => {
    setHeaderHeight(height)
  }, [])

  const renderExploration = (challenge: UserChallenge) => {
    switch (challenge.exploration.state) {
      case UserExplorationState.UNLOCKED:
      case UserExplorationState.ONGOING:
        return <ExplorationOngoing userChallenge={challenge} />
      case UserExplorationState.NOTIFICATION:
      case UserExplorationState.DONE:
        return <ExplorationFinished userChallenge={challenge} />
      default:
        return <ExplorationError />
    }
  }

  return (
    <>
      <CozyBar
        titleKey={'common.title_exploration'}
        displayBackArrow={true}
        isBuilding={true}
      />
      <Header
        setHeaderHeight={defineHeaderHeight}
        desktopTitleKey={'common.title_exploration'}
        displayBackArrow={true}
      ></Header>
      <Content height={headerHeight}>
        {currentChallenge && renderExploration(currentChallenge)}
      </Content>
    </>
  )
}

export default ExplorationView
