import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'
import Button from '@material-ui/core/Button'
import {
  createMockStore,
  mockInitialEcolyoState,
} from '../../../tests/__mocks__/store'
import FormNavigation from './FormNavigation'
import { ProfileTypeStepForm } from 'enum/profileType.enum'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

describe('FormNavigation component', () => {
  let store: any
  beforeEach(() => {
    store = createMockStore(mockInitialEcolyoState)
  })

  it('should be rendered correctly', () => {
    const mockhandlePrevious = jest.fn()
    const mockhandleNext = jest.fn()
    const wrapper = mount(
      <Provider store={store}>
        <FormNavigation
          step={ProfileTypeStepForm.COOKING_FLUID}
          handlePrevious={mockhandlePrevious}
          handleNext={mockhandleNext}
          disableNextButton={false}
        />
      </Provider>
    )
    wrapper.find(Button).at(0).simulate('click')
    wrapper.find(Button).at(1).simulate('click')
    expect(wrapper.find('profile-navigation')).toBeTruthy()
    expect(wrapper.find(Button)).toBeTruthy()
    expect(mockhandlePrevious.mock.calls.length).toEqual(1)
    expect(mockhandleNext.mock.calls.length).toEqual(1)
  })
})
