import { useState, useEffect, Dispatch, SetStateAction } from 'react'
import { useDispatch, useSelector } from 'react-redux'
import { Client, useClient } from 'cozy-client'
import { ChallengeState, UserExploration } from 'models'
import { AppStore } from 'store'
import ExplorationService from 'services/exploration.service'
import { updateUserChallengeList } from 'store/challenge/challenge.actions'
import { UserExplorationState } from 'enum/userExploration.enum'
import { toggleChallengeExplorationNotification } from 'store/global/global.actions'

const useExploration = (): [string, Dispatch<SetStateAction<string>>] => {
  const client: Client = useClient()
  const dispatch = useDispatch()
  const { currentChallenge }: ChallengeState = useSelector(
    (state: AppStore) => state.ecolyo.challenge
  )
  const exploration: UserExploration | null = currentChallenge
    ? currentChallenge.exploration
    : null

  const ecogestureId: string = exploration ? exploration.ecogesture_id : ''

  const [explorationID, setExplorationID] = useState<string>('')

  useEffect(() => {
    let subscribed = true
    if (
      explorationID &&
      currentChallenge?.exploration.id === explorationID &&
      currentChallenge?.exploration.state === UserExplorationState.ONGOING
    ) {
      const checkExplo = async () => {
        const explorationService = new ExplorationService(client)
        explorationService
          .checkExploration(currentChallenge, explorationID)
          .then(updatedChallenge => {
            dispatch(updateUserChallengeList(updatedChallenge))
            if (
              updatedChallenge.exploration.state ===
              UserExplorationState.NOTIFICATION
            ) {
              dispatch(toggleChallengeExplorationNotification(true))
            }
          })
        if (subscribed) setExplorationID('')
      }
      checkExplo()
    }

    return () => {
      subscribed = false
    }
  }, [
    client,
    exploration,
    explorationID,
    ecogestureId,
    currentChallenge,
    dispatch,
  ])

  return [explorationID, setExplorationID]
}

export default useExploration
