import React from 'react'
import { mount } from 'enzyme'
import { Provider } from 'react-redux'
import {
  createMockStore,
  mockInitialEcolyoState,
  mockInitialGlobalState,
} from '../../../tests/__mocks__/store'
import * as reactRedux from 'react-redux'
import KonnectorViewerList from './KonnectorViewerList'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockHistoryPush = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useHistory: () => ({
    push: mockHistoryPush,
  }),
}))

describe('KonnectorViewerList component', () => {
  let store: any
  beforeEach(() => {
    store = createMockStore(mockInitialEcolyoState)
  })

  it('should be rendered correctly', () => {
    const wrapper = mount(
      <Provider store={store}>
        <KonnectorViewerList />
      </Provider>
    ).getElement()
    expect(wrapper).toMatchSnapshot()
  })
  it('should click on card and nav to fluid', async () => {
    const mockUseSelector = jest.spyOn(reactRedux, 'useSelector')

    mockUseSelector.mockReturnValue({
      fluidStatus: mockInitialGlobalState.fluidStatus,
    })
    const wrapper = mount(
      <Provider store={store}>
        <KonnectorViewerList />
      </Provider>
    )
    wrapper.find('.connection-card').first().simulate('click')
    expect(mockHistoryPush).toHaveBeenCalled()
  })
})
