import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { FluidType } from 'enum/fluid.enum'
import React from 'react'
import './Loader.scss'

interface color {
  color?: 'gold' | 'gaz' | 'elec' | 'water' | 'black'
  fluidType?: FluidType
}

/**
 * Loader of Ecolyo, default color is gold
 * @param color 'gold' | 'gaz' | 'elec' | 'water'
 */
const Loader = ({ color = 'gold', fluidType }: color) => {
  const { t } = useI18n()

  switch (fluidType) {
    case FluidType.MULTIFLUID:
      color = 'gold'
      break
    case FluidType.ELECTRICITY:
      color = 'elec'
      break
    case FluidType.GAS:
      color = 'gaz'
      break
    case FluidType.WATER:
      color = 'water'
      break
  }

  return (
    <div
      className={`loader ${color}`}
      aria-busy="true"
      aria-label={t('common.accessibility.loading')}
      title={t('common.accessibility.loading')}
    >
      <div className="bar" />
      <div className="bar" />
      <div className="bar" />
    </div>
  )
}

export default Loader
