import React from 'react'
import { mount } from 'enzyme'
import { BrowserRouter } from 'react-router-dom'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import Navbar from 'components/Navbar/Navbar'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockStore = configureStore([])

describe('Navbar component', () => {
  it('should be rendered correctly with 5 navlink', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <Navbar />
        </BrowserRouter>
      </Provider>
    )
    expect(wrapper.find('NavLink')).toHaveLength(5)
  })

  it('should be rendered correctly with notifications', () => {
    const store = mockStore({
      ecolyo: {
        global: {
          ...globalStateData,
          challengeExplorationNotification: true,
          challengeActionNotification: false,
          challengeDuelNotification: false,
          analysisNotification: true,
        },
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <Navbar />
        </BrowserRouter>
      </Provider>
    )
    expect(wrapper.find('.nb-notif').first().text()).toEqual('1')
    expect(wrapper.find('.nb-notif').last().text()).toEqual('1')
  })

  it('should be rendered correctly without notifications', () => {
    const store = mockStore({
      ecolyo: {
        global: {
          ...globalStateData,
          challengeExplorationNotification: false,
          challengeActionNotification: false,
          challengeDuelNotification: false,
          analysisNotification: false,
        },
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <Navbar />
        </BrowserRouter>
      </Provider>
    )
    expect(wrapper.find('.nb-notif').exists()).toBeFalsy()
  })
})
