import React from 'react'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import PartnerConnectionStepsModal from 'components/PartnerConnectionStepsModal/PartnerConnectionStepsModal'
import { FluidType } from 'enum/fluid.enum'
import { electricitySteps } from '../../../tests/__mocks__/stepsData.mock'
import { Button, IconButton } from '@material-ui/core'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: () => {
      return {
        t: (str: string) => str,
      }
    },
  }
})
const mockGetPartnerSteps = jest.fn()
jest.mock('utils/steps', () => {
  return {
    getPartnerSteps: () => mockGetPartnerSteps,
  }
})
const mockHandleCloseClick = jest.fn()
const mockHandleEndSteps = jest.fn()

describe('PartnerConnectionStepsModal component', () => {
  beforeEach(() => {
    mockGetPartnerSteps.mockClear()
  })

  it('should be rendered correctly', () => {
    mockGetPartnerSteps.mockReturnValue(electricitySteps)
    const component = mount(
      <PartnerConnectionStepsModal
        fluidType={FluidType.ELECTRICITY}
        open={true}
        handleCloseClick={mockHandleCloseClick}
        handleEndSteps={mockHandleEndSteps}
      />
    )
    expect(toJson(component)).toMatchSnapshot()
  })

  it('should close when user click on the button', async () => {
    mockGetPartnerSteps.mockReturnValue(electricitySteps)
    const component = mount(
      <PartnerConnectionStepsModal
        fluidType={FluidType.ELECTRICITY}
        open={true}
        handleCloseClick={mockHandleCloseClick}
        handleEndSteps={mockHandleEndSteps}
      />
    )
    component.find(IconButton).first().simulate('click')
    expect(mockHandleCloseClick).toBeCalled()
  })

  it('should go to next step when user click on next button', () => {
    mockGetPartnerSteps.mockReturnValue(electricitySteps)
    const component = mount(
      <PartnerConnectionStepsModal
        fluidType={FluidType.ELECTRICITY}
        open={true}
        handleCloseClick={mockHandleCloseClick}
        handleEndSteps={mockHandleEndSteps}
      />
    )
    component.find(Button).last().simulate('click')
    const step: string = component
      .find('.partners-connection-step-progress')
      .first()
      .text()
    expect(step).toEqual('2 / 3')
  })

  it('should handle the end of modal when user click on last button', () => {
    mockGetPartnerSteps.mockReturnValue(electricitySteps)
    const component = mount(
      <PartnerConnectionStepsModal
        fluidType={FluidType.ELECTRICITY}
        open={true}
        handleCloseClick={mockHandleCloseClick}
        handleEndSteps={mockHandleEndSteps}
      />
    )
    component.find(Button).last().simulate('click')
    component.find(Button).last().simulate('click')
    const step: string = component
      .find('.partners-connection-step-progress')
      .first()
      .text()
    expect(step).toEqual('3 / 3')
    component.find(Button).last().simulate('click')
    expect(mockHandleEndSteps).toBeCalled()
  })
})
