import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'
import {
  createMockStore,
  mockInitialEcolyoState,
} from '../../../tests/__mocks__/store'
import ProfileTypeFinished from './ProfileTypeFinished'
import { mockProfileType } from '../../../tests/__mocks__/profileType.mock'
import { Button } from '@material-ui/core'

const mockHistoryGoBack = jest.fn()
const mockHistoryPush = jest.fn()

jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useLocation: () => ({
    pathname: '/ecogesture-form',
  }),
  useHistory: () => ({
    goBack: mockHistoryGoBack,
    push: mockHistoryPush,
  }),
}))
jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

describe('ProfileTypeFinished component', () => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  let store: any
  beforeEach(() => {
    jest.clearAllMocks()
    store = createMockStore(mockInitialEcolyoState)
  })
  afterEach(() => {
    jest.clearAllMocks()
  })

  it('should be rendered correctly', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <ProfileTypeFinished profileType={mockProfileType} />
      </Provider>
    )
    expect(wrapper.find('profile-type-finished-card')).toBeTruthy()
  })
  it('should go to ecogesture selection', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ProfileTypeFinished profileType={mockProfileType} />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')
    expect(mockHistoryPush).toHaveBeenCalledWith('/ecogesture-selection')
  })
})
