import React, { useCallback, useEffect, useState } from 'react'
import 'components/ProfileType/profileTypeForm.scss'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import classNames from 'classnames'
import FormProgress from 'components/FormGlobal/FormProgress'
import FormNavigation from 'components/FormGlobal/FormNavigation'
import { remove } from 'lodash'
import {
  IndividualInsulationWork,
  ProfileTypeStepForm,
} from 'enum/profileType.enum'
import {
  ProfileType,
  ProfileTypeAnswer,
  ProfileTypeAnswerChoices,
} from 'models/profileType.model'

interface ProfileTypeFormMultiChoiceProps {
  step: ProfileTypeStepForm
  viewedStep: ProfileTypeStepForm
  profileType: ProfileType
  answerType: ProfileTypeAnswer
  setNextStep: Function
  setPrevioustStep: Function
  isProfileTypeComplete: boolean
}

const ProfileTypeFormMultiChoice: React.FC<ProfileTypeFormMultiChoiceProps> = ({
  step,
  viewedStep,
  profileType,
  answerType,
  setNextStep,
  setPrevioustStep,
  isProfileTypeComplete,
}: ProfileTypeFormMultiChoiceProps) => {
  const { t } = useI18n()
  const [answer, setAnswer] = useState<ProfileTypeAnswerChoices[]>([])

  const handleChange = (value: ProfileTypeAnswerChoices) => {
    let tempAnswer = [...answer]
    if (value === 'none' && !tempAnswer.includes(value)) {
      tempAnswer = [value]
    } else if (tempAnswer.includes(value)) {
      remove(tempAnswer, function (n) {
        return n === 'none' || n === value
      })
    } else {
      remove(tempAnswer, function (n) {
        return n === 'none'
      })
      tempAnswer.push(value)
    }
    setAnswer(tempAnswer)
  }

  const isChecked = (value: ProfileTypeAnswerChoices): boolean => {
    if (answer.includes(value)) {
      return true
    } else {
      return false
    }
  }

  const handlePrevious = useCallback(() => {
    setPrevioustStep(profileType)
  }, [profileType, setPrevioustStep])

  const handleNext = useCallback(() => {
    profileType[answerType.attribute] = answer as IndividualInsulationWork[]
    setNextStep(profileType)
  }, [profileType, setNextStep, answer, answerType.attribute])

  useEffect(() => {
    const attribute = profileType[
      answerType.attribute
    ] as IndividualInsulationWork[]
    if (step < viewedStep || isProfileTypeComplete) {
      setAnswer(attribute)
    }
  }, [step, viewedStep, profileType, answerType, isProfileTypeComplete])

  return (
    <>
      <div className={'profile-form-container'}>
        <FormProgress step={step} formType={'profile'} />
        <div className={'profile-question-label'}>
          {t(
            `profile_type.${ProfileTypeStepForm[step].toLowerCase()}.question`
          )}
        </div>
        <span className="profile-question-hint">
          {t('profile_type.multi_choices')}
        </span>
        {answerType.choices.map(
          (value: ProfileTypeAnswerChoices, index: number) => {
            return value ? (
              <label
                key={index}
                className={classNames('checkbox', {
                  ['answer-checked']: answer.includes(value),
                })}
              >
                <input
                  type={'checkbox'}
                  value={value}
                  name={value.toString()}
                  onChange={() => handleChange(value)}
                  checked={isChecked(value)}
                />
                {t(
                  `profile_type.${ProfileTypeStepForm[
                    step
                  ].toLowerCase()}.${value}`
                )}
              </label>
            ) : null
          }
        )}
      </div>
      <FormNavigation
        step={step}
        handlePrevious={handlePrevious}
        handleNext={handleNext}
        disableNextButton={answer.length < 1}
      />
    </>
  )
}

export default ProfileTypeFormMultiChoice
