import React, { useCallback, useEffect, useState } from 'react'
import 'components/ProfileType/profileTypeForm.scss'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import FormProgress from 'components/FormGlobal/FormProgress'
import FormNavigation from 'components/FormGlobal/FormNavigation'
import { ProfileTypeStepForm } from 'enum/profileType.enum'
import {
  ProfileType,
  ProfileTypeAnswer,
  ProfileTypeAnswerChoices,
} from 'models/profileType.model'

interface ProfileTypeFormNumberProps {
  step: ProfileTypeStepForm
  viewedStep: ProfileTypeStepForm
  profileType: ProfileType
  answerType: ProfileTypeAnswer
  setNextStep: Function
  setPrevioustStep: Function
  isProfileTypeComplete: boolean
}

const ProfileTypeFormNumber: React.FC<ProfileTypeFormNumberProps> = ({
  step,
  viewedStep,
  profileType,
  answerType,
  setNextStep,
  setPrevioustStep,
  isProfileTypeComplete,
}: ProfileTypeFormNumberProps) => {
  const { t } = useI18n()
  const [answer, setAnswer] = useState<ProfileTypeAnswerChoices>('')

  const handlePrevious = useCallback(() => {
    setPrevioustStep(profileType)
  }, [profileType, setPrevioustStep])

  const handleNext = useCallback(() => {
    profileType[answerType.attribute] = answer
    setNextStep(profileType)
  }, [profileType, setNextStep, answer, answerType.attribute])

  useEffect(() => {
    if (step < viewedStep || isProfileTypeComplete) {
      setAnswer(profileType[answerType.attribute])
    }
  }, [step, viewedStep, profileType, answerType, isProfileTypeComplete])

  return (
    <>
      <div className={'profile-form-container'}>
        <FormProgress step={step} formType={'profile'} />
        <div className={'profile-question-label'}>
          {t(
            `profile_type.${ProfileTypeStepForm[step].toLowerCase()}.question`
          )}
        </div>
        {answer != null ? (
          <label className={'text'}>
            <input
              type={'number'}
              value={answer}
              name={answerType.attribute}
              onChange={e => setAnswer(e.target.value)}
              autoFocus
            />
            m²
          </label>
        ) : null}
      </div>
      <FormNavigation
        step={step}
        handlePrevious={handlePrevious}
        handleNext={handleNext}
        disableNextButton={answer === ''}
      />
    </>
  )
}

export default ProfileTypeFormNumber
