import Button from '@material-ui/core/Button'
import Loader from 'components/Loader/Loader'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { challengeStateData } from '../../../tests/__mocks__/challengeStateData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { questionEntity } from '../../../tests/__mocks__/quizData.mock'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import QuizCustomQuestionContent from './QuizCustomQuestionContent'
import QuizExplanationModal from './QuizExplanationModal'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockHistoryPush = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useHistory: () => ({
    push: mockHistoryPush,
  }),
}))

const mockUpdateUserQuiz = jest.fn()
const mockGetCustomQuestion = jest.fn()
jest.mock('services/quiz.service', () => {
  return jest.fn(() => {
    return {
      updateUserQuiz: mockUpdateUserQuiz,
      getCustomQuestion: mockGetCustomQuestion,
    }
  })
})

const mockUserChallengeUpdateFlag = jest.fn()
jest.mock('services/challenge.service', () => {
  return jest.fn(() => {
    return {
      updateUserChallenge: mockUserChallengeUpdateFlag,
    }
  })
})

const mockStore = configureStore([])

describe('QuizCustomQuestionContent component', () => {
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <QuizCustomQuestionContent
          userChallenge={userChallengeData[0]}
          question={questionEntity}
          goBack={mockHistoryPush('/challenges')}
          isLoading={false}
        />
      </Provider>
    )
    wrapper.find('.btn-back').forEach(node => {
      node.simulate('click')
    })
    expect(mockHistoryPush).toHaveBeenCalledWith('/challenges')
    expect(wrapper.find('.question').text()).toEqual(
      questionEntity.questionLabel
    )
    expect(wrapper.find('input')).toHaveLength(3)
  })
  it('should be rendered correctly with loader', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <QuizCustomQuestionContent
          userChallenge={userChallengeData[0]}
          question={questionEntity}
          goBack={mockHistoryPush('/challenges')}
          isLoading={true}
        />
      </Provider>
    )
    expect(wrapper.find(Loader).exists()).toBeTruthy()
  })
  it('should display QuizExplanationModal when click on Button', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <QuizCustomQuestionContent
          userChallenge={userChallengeData[0]}
          question={questionEntity}
          goBack={mockHistoryPush('/challenges')}
          isLoading={false}
        />
      </Provider>
    )
    const answer = questionEntity.answers[0].answerLabel
    expect(
      wrapper
        .find({ type: 'radio' })
        .at(0)
        .simulate('change', { target: { value: answer } })
    )
    expect(wrapper.find(Button).exists()).toBeTruthy()
    wrapper.find('.btn-secondary-negative').forEach(node => {
      node.simulate('click')
    })
    expect(mockUpdateUserQuiz).toHaveBeenCalledWith(
      userChallengeData[0].quiz,
      questionEntity.answers[0].isTrue
    )
    expect(wrapper.find(QuizExplanationModal).exists()).toBeTruthy()
    expect(wrapper.find(QuizExplanationModal).prop('open')).toBeTruthy()
  })
})
