/* eslint-disable react/display-name */
import React from 'react'
import { mount } from 'enzyme'
import { Provider } from 'react-redux'
import * as reactRedux from 'react-redux'
import {
  createMockStore,
  mockInitialEcolyoState,
} from '../../../tests/__mocks__/store'
import QuizQuestion from './QuizQuestion'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import { UserQuestionState } from 'enum/userQuiz.enum'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockHistoryPush = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useHistory: () => ({
    push: mockHistoryPush,
  }),
}))

const mockgetCustomQuestion = jest.fn()
jest.mock('services/quiz.service', () => {
  return jest.fn(() => {
    return {
      getCustomQuestion: mockgetCustomQuestion,
    }
  })
})

jest.mock('components/Quiz/QuizCustomQuestionContent', () => () => (
  <div id="quizcustomquestioncontent"></div>
))
jest.mock('components/Quiz/QuizQuestionContent', () => () => (
  <div id="quizquestioncontent"></div>
))
const useSelectorSpy = jest.spyOn(reactRedux, 'useSelector')

describe('QuizQuestion component', () => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  let store: any
  beforeEach(() => {
    store = createMockStore(mockInitialEcolyoState)
    useSelectorSpy.mockClear()
  })

  it('should be rendered correctly with question', () => {
    const wrapper = mount(
      <Provider store={store}>
        <QuizQuestion userChallenge={userChallengeData[0]} />
      </Provider>
    )
    expect(wrapper.find('#quizquestioncontent').exists()).toBeTruthy()
    expect(wrapper.find('#quizcustomquestioncontent').exists()).toBeFalsy()
  })

  it('should be rendered correctly with customQuestion', () => {
    const updateUserChallengeData = {
      ...userChallengeData[0],
    }
    updateUserChallengeData.quiz.questions.forEach(
      answer => (answer.result = UserQuestionState.CORRECT)
    )
    const wrapper = mount(
      <Provider store={store}>
        <QuizQuestion userChallenge={updateUserChallengeData} />
      </Provider>
    )
    expect(wrapper.find('#quizquestioncontent').exists()).toBeFalsy()
    expect(wrapper.find('#quizcustomquestioncontent').exists()).toBeTruthy()
  })
})
