import React, { useState, useEffect } from 'react'
import './quizQuestion.scss'
import QuizQuestionContent from 'components/Quiz/QuizQuestionContent'
import QuizCustomQuestionContent from 'components/Quiz/QuizCustomQuestionContent'
import { QuestionEntity, UserChallenge } from 'models'
import { useHistory } from 'react-router-dom'
import { useSelector } from 'react-redux'
import { AppStore } from 'store'
import QuizService from 'services/quiz.service'
import { Client, useClient } from 'cozy-client'

interface QuizQuestion {
  userChallenge: UserChallenge
}

const QuizQuestion: React.FC<QuizQuestion> = ({
  userChallenge,
}: QuizQuestion) => {
  const questionsIsLocked: boolean = userChallenge.quiz.questions.some(
    answer => answer.result == 0
  )
  const [question, setQuestion] = useState<QuestionEntity>()
  const [isCustomQuest, setIsCustomQuest] = useState<boolean>(
    !questionsIsLocked
  )
  const [customQuestionLoading, setCustomQuestionLoading] =
    useState<boolean>(false)
  const client: Client = useClient()
  const { fluidTypes } = useSelector((state: AppStore) => state.ecolyo.global)
  const history = useHistory()

  const goBack = () => {
    history.push('/challenges')
  }

  useEffect(() => {
    let subscribed = true
    async function loadCustomQuestion() {
      const quizService: QuizService = new QuizService(client)
      const customQuestion: QuestionEntity =
        await quizService.getCustomQuestion(
          userChallenge.quiz.customQuestion,
          fluidTypes
        )
      if (subscribed) {
        setQuestion(customQuestion)
        setCustomQuestionLoading(false)
      }
    }
    if (isCustomQuest) {
      setCustomQuestionLoading(true)
      loadCustomQuestion()
    }
    return () => {
      subscribed = false
    }
  }, [client, fluidTypes, isCustomQuest, userChallenge.quiz.customQuestion])

  return (
    <>
      {isCustomQuest ? (
        <QuizCustomQuestionContent
          userChallenge={userChallenge}
          goBack={goBack}
          question={question}
          isLoading={customQuestionLoading}
        />
      ) : (
        <QuizQuestionContent
          userChallenge={userChallenge}
          setIsCustomQuest={setIsCustomQuest}
          goBack={goBack}
        />
      )}
    </>
  )
}

export default QuizQuestion
