import MailService from './mail.service'
import mockClient from '../../tests/__mocks__/client'

describe('Mail service', () => {
  const mailService = new MailService()

  describe('SendMail service', () => {
    it('should return void when mail is sent', async () => {
      const mockMailData = {
        mode: 'noreply',
        subject: '[Ecolyo] - Bienvenue',
        parts: [
          {
            type: 'text/html',
            body: '<html>Body</html>',
          },
        ],
      }
      const result: void = await mailService.SendMail(mockClient, mockMailData)
      expect(result).toEqual(undefined)
    })

    it('should throw error when failed to send mail', async () => {
      let error
      const mockMailData = {
        mode: 'noreply',
        subject: '[Ecolyo] - Bienvenue',
        parts: [
          {
            type: 'text/html',
            body: '<html>Body</html>',
          },
        ],
      }
      mockClient.collection('').create.mockImplementationOnce(() => {
        throw new Error()
      })
      try {
        await mailService.SendMail(mockClient, mockMailData)
      } catch (err) {
        error = err
      }
      expect(error).toEqual(new Error('Failed to send mail'))
    })
  })
})
