import TimePeriodService from './timePeriod.service'
import { TimeStep } from 'enum/timeStep.enum'
import { DateTime } from 'luxon'
import { TimePeriod } from 'models'
import { FluidType } from 'enum/fluid.enum'

const randomDate = DateTime.fromISO('2020-10-10T08:00:00.000Z', {
  zone: 'utc',
})
const unknowTimeStep = 999
describe('timePeriod service', () => {
  const timePeriodService = new TimePeriodService()
  describe('getTimePeriods method', () => {
    const lastDatePeriod = DateTime.fromISO('2020-10-31T08:00:00.000Z', {
      zone: 'utc',
    })
    const fluidTypes: FluidType[] = [0, 1, 2]
    const comparisonTimePeriod: TimePeriod = {
      startDate: DateTime.fromISO('2020-08-01T00:00:00.000Z', {
        zone: 'utc',
      }),
      endDate: DateTime.fromISO('2020-08-31T00:00:00.000Z', {
        zone: 'utc',
      }),
    }
    const timePeriod: TimePeriod = {
      startDate: DateTime.fromISO('2020-09-01T00:00:00.000Z', {
        zone: 'utc',
      }),
      endDate: DateTime.fromISO('2020-09-30T23:59:59.999Z', {
        zone: 'utc',
      }),
    }
    let result = null
    it('should return the current timePeriod  and the comparison timePeriod for DAY', () => {
      result = timePeriodService.getTimePeriods(
        lastDatePeriod,
        fluidTypes,
        TimeStep.DAY
      )
      expect(result).toEqual({
        timePeriod,
        comparisonTimePeriod,
      })
    })
    it('should return the current timePeriod  and the comparison timePeriod for MONTH', () => {
      comparisonTimePeriod.endDate = DateTime.fromISO(
        '2020-08-31T23:59:59.999Z',
        {
          zone: 'utc',
        }
      )
      comparisonTimePeriod.startDate = DateTime.fromISO(
        '2020-08-01T00:00:00.000Z',
        {
          zone: 'utc',
        }
      )

      timePeriod.startDate = DateTime.fromISO('2020-09-01T00:00:00.000Z', {
        zone: 'utc',
      })
      timePeriod.endDate = DateTime.fromISO('2020-09-30T23:59:59.999Z', {
        zone: 'utc',
      })
      result = timePeriodService.getTimePeriods(
        lastDatePeriod,
        fluidTypes,
        TimeStep.MONTH
      )
      expect(result).toEqual({
        timePeriod,
        comparisonTimePeriod,
      })
    })
    it('should return the current timePeriod  and the comparison timePeriod for YEAR', () => {
      comparisonTimePeriod.endDate = DateTime.fromISO(
        '2018-12-31T23:59:59.999Z',
        {
          zone: 'utc',
        }
      )
      comparisonTimePeriod.startDate = DateTime.fromISO(
        '2018-01-01T00:00:00.000Z',
        {
          zone: 'utc',
        }
      )

      timePeriod.startDate = DateTime.fromISO('2019-01-01T00:00:00.000Z', {
        zone: 'utc',
      })
      timePeriod.endDate = DateTime.fromISO('2019-12-31T23:59:59.999Z', {
        zone: 'utc',
      })
      result = timePeriodService.getTimePeriods(
        lastDatePeriod,
        fluidTypes,
        TimeStep.YEAR
      )
      expect(result).toEqual({
        timePeriod,
        comparisonTimePeriod,
      })
    })
  })
  describe('calculateFluidTypesOffset method', () => {
    let fluidTypes: FluidType[] = [0, 1, 2]
    it('should return the offset day in function of the fluid', () => {
      let result = timePeriodService.calculateFluidTypesOffset(fluidTypes)
      expect(result).toBe(5)

      fluidTypes = [0]
      result = timePeriodService.calculateFluidTypesOffset(fluidTypes)
      expect(result).toBe(3)
      fluidTypes = [1]
      result = timePeriodService.calculateFluidTypesOffset(fluidTypes)
      expect(result).toBe(5)

      fluidTypes = [2]
      result = timePeriodService.calculateFluidTypesOffset(fluidTypes)
      expect(result).toBe(5)
    })
  })
  describe('applyOffsetToDate method', () => {
    it('should return new date with offset day apply', () => {
      let expectedDate = DateTime.fromISO('2020-10-07T08:00:00.000Z', {
        zone: 'utc',
      })
      let result = timePeriodService.applyOffsetToDate(randomDate, 3)
      expect(result).toEqual(expectedDate)

      expectedDate = DateTime.fromISO('2020-09-25T08:00:00.000Z', {
        zone: 'utc',
      })
      result = timePeriodService.applyOffsetToDate(randomDate, 15)
      expect(result).toEqual(expectedDate)
    })
  })

  describe('getComparisonTimePeriod method', () => {
    it('should return the comparison TimePeriod for HALF_AN_HOUR', () => {
      const timePeriod: TimePeriod = {
        startDate: DateTime.fromISO('2020-10-10T00:00:00.000Z', {
          zone: 'utc',
        }),
        endDate: DateTime.fromISO('2020-10-10T23:59:59.999Z', {
          zone: 'utc',
        }),
      }
      const expectedComparisonDateTime = {
        startDate: DateTime.fromISO('2020-10-09T00:00:00.000Z', {
          zone: 'utc',
        }),
        endDate: DateTime.fromISO('2020-10-09T23:59:59.999Z', {
          zone: 'utc',
        }),
      }
      const result = timePeriodService.getComparisonTimePeriod(
        timePeriod,
        TimeStep.HALF_AN_HOUR
      )
      expect(result).toEqual(expectedComparisonDateTime)
    })
    it('should return the comparison TimePeriod for WEEK', () => {
      const timePeriod: TimePeriod = {
        startDate: DateTime.fromISO('2020-10-12T00:00:00.000Z', {
          zone: 'utc',
        }),
        endDate: DateTime.fromISO('2020-10-18T23:59:59.999Z', {
          zone: 'utc',
        }),
      }
      const expectedComparisonDateTime = {
        startDate: DateTime.fromISO('2020-10-05T00:00:00.000Z', {
          zone: 'utc',
        }),
        endDate: DateTime.fromISO('2020-10-11T23:59:59.999Z', {
          zone: 'utc',
        }),
      }
      const result = timePeriodService.getComparisonTimePeriod(
        timePeriod,
        TimeStep.WEEK
      )
      expect(result).toEqual(expectedComparisonDateTime)
    })
    it('should return the comparison TimePeriod for DAY', () => {
      const timePeriod: TimePeriod = {
        startDate: DateTime.fromISO('2020-10-01T00:00:00.000Z', {
          zone: 'utc',
        }),
        endDate: DateTime.fromISO('2020-10-31T23:59:59.999Z', {
          zone: 'utc',
        }),
      }
      const expectedComparisonDateTime = {
        startDate: DateTime.fromISO('2020-09-01T00:00:00.000Z', {
          zone: 'utc',
        }),
        endDate: DateTime.fromISO('2020-09-30T00:00:00.000Z', {
          zone: 'utc',
        }),
      }
      const result = timePeriodService.getComparisonTimePeriod(
        timePeriod,
        TimeStep.DAY
      )
      expect(result).toEqual(expectedComparisonDateTime)
    })
    it('should return the comparison TimePeriod for MONTH', () => {
      const timePeriod: TimePeriod = {
        startDate: DateTime.fromISO('2020-10-07T08:00:00.000Z', {
          zone: 'utc',
        }),
        endDate: DateTime.fromISO('2020-10-14T08:00:00.000Z', {
          zone: 'utc',
        }),
      }
      const expectedComparisonDateTime = {
        startDate: DateTime.fromISO('2020-09-07T00:00:00.000Z', {
          zone: 'utc',
        }),
        endDate: DateTime.fromISO('2020-09-30T23:59:59.999Z', {
          zone: 'utc',
        }),
      }
      const result = timePeriodService.getComparisonTimePeriod(
        timePeriod,
        TimeStep.MONTH
      )
      expect(result).toEqual(expectedComparisonDateTime)
    })
    it('should return the comparison TimePeriod for YEAR', () => {
      const timePeriod: TimePeriod = {
        startDate: DateTime.fromISO('2020-10-07T08:00:00.000Z', {
          zone: 'utc',
        }),
        endDate: DateTime.fromISO('2020-10-14T08:00:00.000Z', {
          zone: 'utc',
        }),
      }
      const expectedComparisonDateTime = {
        startDate: DateTime.fromISO('2019-10-07T00:00:00.000Z', {
          zone: 'utc',
        }),
        endDate: DateTime.fromISO('2019-12-31T23:59:59.999Z', {
          zone: 'utc',
        }),
      }
      const result = timePeriodService.getComparisonTimePeriod(
        timePeriod,
        TimeStep.YEAR
      )
      expect(result).toEqual(expectedComparisonDateTime)
    })
    it('should return an error because of unknown TimeStep', () => {
      const timePeriod: TimePeriod = {
        startDate: DateTime.fromISO('2020-10-07T08:00:00.000Z', {
          zone: 'utc',
        }),
        endDate: DateTime.fromISO('2020-10-14T08:00:00.000Z', {
          zone: 'utc',
        }),
      }
      try {
        timePeriodService.getComparisonTimePeriod(timePeriod, unknowTimeStep)
      } catch (error) {
        expect(error).toEqual(new Error('TimeStep unknown'))
      }
    })
  })

  describe('getLastDayOfCompletePeriod method', () => {
    it('should return the date of the last day of a completed period for HALF_AN_HOUR', () => {
      const expectedDate = DateTime.fromISO('2020-10-10T00:00:00.000Z', {
        zone: 'utc',
      })
      const result = timePeriodService.getLastDayOfCompletePeriod(
        randomDate,
        TimeStep.HALF_AN_HOUR
      )
      expect(result).toEqual(expectedDate)
    })
    it('should return the date of the last day of a completed period for WEEK', () => {
      const expectedDate = DateTime.fromISO('2020-10-04T00:00:00.000Z', {
        zone: 'utc',
      })
      const result = timePeriodService.getLastDayOfCompletePeriod(
        randomDate,
        TimeStep.WEEK
      )
      expect(result).toEqual(expectedDate)
    })
    it('should return the date of the last day of a completed period for DAY', () => {
      const expectedDate = DateTime.fromISO('2020-09-30T00:00:00.000Z', {
        zone: 'utc',
      })
      const result = timePeriodService.getLastDayOfCompletePeriod(
        randomDate,
        TimeStep.DAY
      )
      expect(result).toEqual(expectedDate)
    })
    it('should return the date of the last day of a completed period for MONTH', () => {
      const expectedDate = DateTime.fromISO('2020-09-30T00:00:00.000Z', {
        zone: 'utc',
      })
      const result = timePeriodService.getLastDayOfCompletePeriod(
        randomDate,
        TimeStep.MONTH
      )
      expect(result).toEqual(expectedDate)
    })
    it('should return the date of the last day of a completed period for YEAR', () => {
      const expectedDate = DateTime.fromISO('2019-12-31T00:00:00.000Z', {
        zone: 'utc',
      })
      const result = timePeriodService.getLastDayOfCompletePeriod(
        randomDate,
        TimeStep.YEAR
      )
      expect(result).toEqual(expectedDate)
    })
    it('should return an error because of unknown TimeStep', () => {
      try {
        timePeriodService.getLastDayOfCompletePeriod(randomDate, unknowTimeStep)
      } catch (error) {
        expect(error).toEqual(new Error('TimeStep unknown'))
      }
    })
  })

  describe('getLastDayOfTimePeriod method', () => {
    it('should return the date of the last day of current period for HALF_AN_HOUR', () => {
      const expectedDate = DateTime.fromISO('2020-10-10T00:00:00.000Z', {
        zone: 'utc',
      })
      const result = timePeriodService.getLastDayOfTimePeriod(
        randomDate,
        TimeStep.HALF_AN_HOUR
      )
      expect(result).toEqual(expectedDate)
    })
    it('should return the date of the last day of current period for WEEK', () => {
      const expectedDate = DateTime.fromISO('2020-10-11T23:59:59.999Z', {
        zone: 'utc',
      })
      const result = timePeriodService.getLastDayOfTimePeriod(
        randomDate,
        TimeStep.WEEK
      )
      expect(result).toEqual(expectedDate)
    })
    it('should return the date of the last day of current period for DAY', () => {
      const expectedDate = DateTime.fromISO('2020-10-31T23:59:59.999Z', {
        zone: 'utc',
      })
      const result = timePeriodService.getLastDayOfTimePeriod(
        randomDate,
        TimeStep.DAY
      )
      expect(result).toEqual(expectedDate)
    })
    it('should return the date of the last day of current period', () => {
      const expectedDate = DateTime.fromISO('2020-10-31T00:00:00.000Z', {
        zone: 'utc',
      })
      const result = timePeriodService.getLastDayOfTimePeriod(
        randomDate,
        TimeStep.MONTH
      )
      expect(result).toEqual(expectedDate)
    })
    it('should return the date of the last day of current period', () => {
      const expectedDate = DateTime.fromISO('2020-12-31T00:00:00.000Z', {
        zone: 'utc',
      })
      const result = timePeriodService.getLastDayOfTimePeriod(
        randomDate,
        TimeStep.YEAR
      )
      expect(result).toEqual(expectedDate)
    })
    it('should return the date of the last day of current period', () => {
      try {
        timePeriodService.getLastDayOfTimePeriod(randomDate, unknowTimeStep)
      } catch (error) {
        expect(error).toEqual(new Error('TimeStep unknown'))
      }
    })
  })

  describe('getStartDateFromEndDateByTimeStep method', () => {
    it('should return the date of the first day of a period for HALF_AN_HOUR', () => {
      const expectedDate = DateTime.fromISO('2020-10-10T00:00:00.000Z', {
        zone: 'utc',
      })
      const result = timePeriodService.getStartDateFromEndDateByTimeStep(
        randomDate,
        TimeStep.HALF_AN_HOUR
      )
      expect(result).toEqual(expectedDate)
    })
    it('should return the date of the last day of current period for WEEK', () => {
      const expectedDate = DateTime.fromISO('2020-10-05T00:00:00.000Z', {
        zone: 'utc',
      })
      const result = timePeriodService.getStartDateFromEndDateByTimeStep(
        randomDate,
        TimeStep.WEEK
      )
      expect(result).toEqual(expectedDate)
    })
    it('should return the date of the last day of current period for DAY', () => {
      const expectedDate = DateTime.fromISO('2020-10-01T00:00:00.000Z', {
        zone: 'utc',
      })
      const result = timePeriodService.getStartDateFromEndDateByTimeStep(
        randomDate,
        TimeStep.DAY
      )
      expect(result).toEqual(expectedDate)
    })
    it('should return the date of the last day of current period for MONTH', () => {
      const expectedDate = DateTime.fromISO('2020-10-01T00:00:00.000Z', {
        zone: 'utc',
      })
      const result = timePeriodService.getStartDateFromEndDateByTimeStep(
        randomDate,
        TimeStep.MONTH
      )
      expect(result).toEqual(expectedDate)
    })
    it('should return the date of the last day of current period for YEAR', () => {
      const expectedDate = DateTime.fromISO('2020-01-01T00:00:00.000Z', {
        zone: 'utc',
      })
      const result = timePeriodService.getStartDateFromEndDateByTimeStep(
        randomDate,
        TimeStep.YEAR
      )
      expect(result).toEqual(expectedDate)
    })
    it('should return the date of the last day of current period', () => {
      try {
        timePeriodService.getStartDateFromEndDateByTimeStep(
          randomDate,
          unknowTimeStep
        )
      } catch (error) {
        expect(error).toEqual(new Error('TimeStep unknown'))
      }
    })
  })
})
