import {
  createMockStore,
  mockInitialEcolyoState,
} from '../../../tests/__mocks__/store'
import { mockProfileEcogesture } from '../../../tests/__mocks__/profileEcogesture.mock'
import {
  updateProfileEcogesture,
  UPDATE_PROFILEECOGESTURE,
} from './profileEcogesture.actions'

const mockUpdateProfileEcogesture = jest.fn()
const mockNewProfileEcogestureEntry = jest.fn()
jest.mock('services/profileEcogesture.service', () => {
  return jest.fn(() => {
    return {
      updateProfileEcogesture: mockUpdateProfileEcogesture,
      newProfileEcogestureEntry: mockNewProfileEcogestureEntry,
    }
  })
})

describe('profileEcogesture actions', () => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  let store: any
  beforeEach(() => {
    store = createMockStore(mockInitialEcolyoState)
  })
  it('should create an UPDATE_PROFILEECOGESTURE action when ecogestureProfile is updated', async () => {
    mockUpdateProfileEcogesture.mockResolvedValueOnce(mockProfileEcogesture)
    const expectedActions = [
      {
        type: UPDATE_PROFILEECOGESTURE,
        payload: mockProfileEcogesture,
      },
    ]
    await store.dispatch(updateProfileEcogesture(mockProfileEcogesture))
    expect(store.getActions()).toEqual(expectedActions)
  })

  it('should not create action when ProfileEcogesture is not updated', async () => {
    mockUpdateProfileEcogesture.mockResolvedValueOnce(null)
    await store.dispatch(updateProfileEcogesture(mockProfileEcogesture))
    expect(store.getActions()).toEqual([])
  })
})
