import ElecIcon from '../assets/icons/visu/elec.svg'
import ElecUnactive from '../assets/icons/visu/elec-grey.svg'
import WaterIcon from '../assets/icons/visu/water.svg'
import WaterUnactive from '../assets/icons/visu/water-grey.svg'
import GasIcon from '../assets/icons/visu/gas.svg'
import GasUnactive from '../assets/icons/visu/gas-grey.svg'
import ElecSmallIcon from '../assets/icons/visu/elec-small.svg'
import WaterSmallIcon from '../assets/icons/visu/water-small.svg'
import GasSmallIcon from '../assets/icons/visu/gas-small.svg'
import AddElecIcon from 'assets/icons/ico/add-elec.svg'
import AddWaterIcon from 'assets/icons/ico/add-water.svg'
import AddGasIcon from 'assets/icons/ico/add-gas.svg'
import ElecParamIcon from 'assets/icons/visu/elec-param.svg'
import Multi from 'assets/icons/visu/multi.svg'
import MultiUnactive from 'assets/icons/visu/multi-grey.svg'
import DisconnectedActive from 'assets/icons/visu/disconnected.svg'
import Disconnected from 'assets/icons/visu/disconnected-grey.svg'
import WaterParamIcon from 'assets/icons/visu/water-param.svg'
import GasParamIcon from 'assets/icons/visu/gas-param.svg'
import iconEnedisLogo from 'assets/icons/visu/enedis-logo.svg'
import iconEnedisWhiteLogo from 'assets/icons/visu/enedis-logo-white.svg'
import iconGrdfLogo from 'assets/icons/visu/grdf-logo.svg'
import iconGrdfWhiteLogo from 'assets/icons/visu/grdf-logo-white.svg'
import iconEglLogo from 'assets/icons/visu/egl-logo.svg'
import iconEglWhiteLogo from 'assets/icons/visu/egl-logo-white.svg'
import { FluidType } from '../enum/fluid.enum'
import ConfigService from 'services/fluidConfig.service'

/**
 * Return an icon corresponding to FuildType enum
 * @param type FluidType
 */
export function getPicto(type: FluidType, small = false) {
  switch (type) {
    case FluidType.ELECTRICITY:
      return small ? ElecSmallIcon : ElecIcon
    case FluidType.WATER:
      return small ? WaterSmallIcon : WaterIcon
    case FluidType.GAS:
      return small ? GasSmallIcon : GasIcon
    case FluidType.MULTIFLUID:
      return Multi
    default:
      return ElecIcon
  }
}
/**
 * Return an icon corresponding to add FuildType enum
 * @param type FluidType
 */
export function getAddPicto(type: FluidType) {
  switch (type) {
    case FluidType.ELECTRICITY:
      return AddElecIcon
    case FluidType.WATER:
      return AddWaterIcon
    case FluidType.GAS:
      return AddGasIcon
    default:
      return ElecIcon
  }
}

export function getParamPicto(type: FluidType) {
  switch (type) {
    case FluidType.ELECTRICITY:
      return ElecParamIcon
    case FluidType.WATER:
      return WaterParamIcon
    case FluidType.GAS:
      return GasParamIcon
    default:
      return ElecParamIcon
  }
}

/**
 * Return an icon corresponding to FuildType enum
 * @param type FluidType
 */
export function getNavPicto(
  type: FluidType,
  active: boolean,
  connected: boolean
) {
  switch (type) {
    case FluidType.ELECTRICITY:
      return connected
        ? active
          ? ElecSmallIcon
          : ElecUnactive
        : active
        ? DisconnectedActive
        : Disconnected
    case FluidType.WATER:
      return connected
        ? active
          ? WaterSmallIcon
          : WaterUnactive
        : active
        ? DisconnectedActive
        : Disconnected
    case FluidType.GAS:
      return connected
        ? active
          ? GasSmallIcon
          : GasUnactive
        : active
        ? DisconnectedActive
        : Disconnected
    case FluidType.MULTIFLUID:
      return connected
        ? active
          ? Multi
          : MultiUnactive
        : active
        ? DisconnectedActive
        : Disconnected
    default:
      return ElecIcon
  }
}

/**
 * Return an partner icon corresponding to FuildType enum
 * @param slug string
 * @param blackLogo boolean - define the color of the logo (black or white)
 */
export function getPartnerPicto(slug: string, blackLogo = true) {
  const fluidconfig = new ConfigService().getFluidConfig()
  switch (slug) {
    case fluidconfig[FluidType.ELECTRICITY].konnectorConfig.slug:
      return blackLogo ? iconEnedisLogo : iconEnedisWhiteLogo
    case fluidconfig[FluidType.WATER].konnectorConfig.slug:
      return blackLogo ? iconEglLogo : iconEglWhiteLogo
    case fluidconfig[FluidType.GAS].konnectorConfig.slug:
      return blackLogo ? iconGrdfLogo : iconGrdfWhiteLogo
    default:
      return ''
  }
}
